@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# $Id: rst2html4.py 8927 2022-01-03 23:50:05Z milde $
+# $Id: rst2html4.py 9115 2022-07-28 17:06:24Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -14,7 +14,7 @@ and almost to HTML 4.01 transitional (except for closing empty tags).
 try:
     import locale
     locale.setlocale(locale.LC_ALL, '')
-except:
+except Exception:
     pass
 
 from docutils.core import publish_cmdline, default_description
