@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf8 -*-
 # :Copyright: © 2015 Günter Milde.
 # :License: Released under the terms of the `2-Clause BSD license`_, in short:
 #
@@ -8,28 +7,27 @@
 #    notice and this notice are preserved.
 #    This file is offered as-is, without any warranty.
 #
-# .. _2-Clause BSD license: http://www.spdx.org/licenses/BSD-2-Clause
+# .. _2-Clause BSD license: https://opensource.org/licenses/BSD-2-Clause
 #
-# Revision: $Revision: 8410 $
-# Date: $Date: 2019-11-04 22:14:43 +0100 (Mo, 04. Nov 2019) $
+# Revision: $Revision: 9021 $
+# Date: $Date: 2022-03-04 16:54:22 +0100 (Fr, 04. Mär 2022) $
 
 """
 A minimal front end to the Docutils Publisher, producing HTML 5 documents.
 
-The output also conforms to XHTML 1.0 transitional
-(except for the doctype declaration).
+The output is also valid XML.
 """
 
 try:
-    import locale # module missing in Jython
+    import locale  # module missing in Jython
     locale.setlocale(locale.LC_ALL, '')
 except locale.Error:
     pass
 
 from docutils.core import publish_cmdline, default_description
 
-description = (u'Generates HTML 5 documents from standalone '
-               u'reStructuredText sources '
+description = ('Generates HTML5 documents from standalone '
+               'reStructuredText sources.\n'
                + default_description)
 
 publish_cmdline(writer_name='html5', description=description)
