@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# $Id: rst2s5.py 8927 2022-01-03 23:50:05Z milde $
+# $Id: rst2s5.py 9115 2022-07-28 17:06:24Z milde $
 # Author: Chris Liechti <cliechti@gmx.net>
 # Copyright: This module has been placed in the public domain.
 
@@ -12,7 +12,7 @@ the S5 template system.
 try:
     import locale
     locale.setlocale(locale.LC_ALL, '')
-except:
+except Exception:
     pass
 
 from docutils.core import publish_cmdline, default_description
