@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# $Id: rstpep2html.py 8927 2022-01-03 23:50:05Z milde $
+# $Id: rstpep2html.py 9115 2022-07-28 17:06:24Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -12,7 +12,7 @@ A minimal front end to the Docutils Publisher, producing HTML from PEP
 try:
     import locale
     locale.setlocale(locale.LC_ALL, '')
-except:
+except Exception:
     pass
 
 from docutils.core import publish_cmdline, default_description
